@@ -2,4 +2,4 @@
 # =================================
 #  ルートフォルダパス
 # =================================
-LOG_PATH = "abfss://filesystem@bigdatademolki.dfs.core.windows.net/log/"
+LOG_PATH = "log/"
